@@ -108,7 +108,7 @@ sub _version_2_dec {
     $ver =~ m/^(\d+)\.(\d+)\.(\d+)$/ and
       $dec = $1 + $2 / 1000 + $3 / 1000000;
 
-    return $dec;
+    return sprintf( "%.6f", $dec );
 }
 
 sub _init_config {
@@ -269,12 +269,13 @@ sub patch_wxwidgets {
 
     print "Patching wxWidgets...\n";
 
-    chdir File::Spec->rel2abs
-              ( $self->notes( 'build_data' )->{data}{directory} );
+    my $wx_dir = $self->notes( 'build_data' )->{data}{directory};
+    my $build_dir = File::Spec->rel2abs( $wx_dir );
+    chdir $wx_dir;
 
     foreach my $i ( @patches ) {
         print "Applying patch: ", $i, "\n";
-        my $cmd = $self->_patch_command( $old_dir, $i );
+        my $cmd = $self->_patch_command( $build_dir, $i );
         print $cmd, "\n";
         system $cmd and die 'Error: ', $?;
     }
@@ -285,7 +286,8 @@ sub patch_wxwidgets {
 sub _patch_command {
     my( $self, $base_dir, $patch_file ) = @_;
 
-    my $cmd = $^X . ' ' . File::Spec->catfile( $base_dir,
+    $patch_file = File::Spec->abs2rel( $patch_file, $base_dir );
+    my $cmd = $^X . ' ' . File::Spec->catfile( File::Spec->updir,
                                                qw(inc bin patch) )
       . " -N -p0 -u -b .bak < $patch_file";
 
@@ -335,7 +337,8 @@ sub awx_monolithic { $_[0]->args( 'monolithic' ) ? 1 : 0 }
 sub awx_is_monolithic { $_[0]->awx_monolithic }
 sub awx_debug { $_[0]->args( 'debug' ) ? 1 : 0 }
 sub awx_is_debug { $_[0]->awx_debug }
-sub awx_unicode { $_[0]->args( 'unicode' ) ? 1 : 0 }
+sub awx_unicode { $_[0]->notes( 'build_wx_unicode' )
+                    || $_[0]->args( 'unicode' ) ? 1 : 0 }
 sub awx_is_unicode { $_[0]->awx_unicode }
 sub awx_mslu { 0 }
 sub awx_is_mslu { $_[0]->awx_mslu }
