@@ -37,7 +37,8 @@ EOT
 
 sub _patch_command {
     my( $self, $base_dir, $patch_file ) = @_;
-    my $patch_exe = File::Spec->catfile( $base_dir, qw(inc bin patch.exe) );
+    my $patch_exe = File::Spec->catfile( File::Spec->updir,
+                                         qw(inc bin patch.exe) );
 
     my $cmd = qq{perl -pe "" -- $patch_file} .
               qq{ | $patch_exe -N -p0 -u -b -z .bak};
@@ -82,7 +83,7 @@ sub awx_wx_config_data {
     my $self = shift;
     my $wxdir_b = $ENV{WXDIR};
     my $wxdir = $self->notes( 'build_wx' ) ?
-      awx_install_arch_dir( 'rEpLaCe' ) : $wxdir_b;
+      awx_install_arch_dir( $self, 'rEpLaCe' ) : $wxdir_b;
 
     return { 'wxdir'       => $wxdir,
              'wxdir_build' => $wxdir_b,
@@ -98,7 +99,7 @@ sub awx_configure {
 
     $config{prefix} = $self->wx_config( 'wxdir' );
     $config{config}{toolkit} = $self->is_wince ? 'wce' : 'msw';
-    $config{shared_library_path} = awx_install_arch_file( "rEpLaCe/lib" );
+    $config{shared_library_path} = awx_install_arch_file( $self, "rEpLaCe/lib" );
 
     die "Unable to find setup.h directory"
       unless $self->wx_config( 'cxxflags' )
@@ -208,7 +209,7 @@ sub awx_get_package {
     return 'WinCE' if $INC{'Cross.pm'};
 
     SWITCH: {
-        local $_ = $Config{ccname};
+        local $_ = $Config{ccname} || $Config{cc};
 
         /^cl/i  and $package = 'Win32_MSVC'  and last SWITCH;
         /^gcc/i and $package = 'Win32_MinGW' and last SWITCH;
@@ -230,7 +231,7 @@ sub awx_get_package {
 # been explicitly disabled
 sub awx_mslu {
     return $_[0]->args( 'mslu' ) if defined $_[0]->args( 'mslu' );
-    return $_[0]->awx_unicode;
+    return $_[0]->args( 'unicode' );
 }
 
 sub massage_environment {
